@@ -5,46 +5,55 @@
     <name>PasswordDialog</name>
     <message>
         <location filename="../passworddialog.ui" line="6"/>
+        <location filename="../obj-x86_64-linux-gnu/lxqt-sudo_autogen/include/ui_passworddialog.h" line="171"/>
         <source>LXQt sudo</source>
         <translation>LXQt sudo</translation>
     </message>
     <message>
         <location filename="../passworddialog.ui" line="42"/>
+        <location filename="../obj-x86_64-linux-gnu/lxqt-sudo_autogen/include/ui_passworddialog.h" line="173"/>
         <source>Copy command to clipboard</source>
         <translation>Kopier kommando til utklippsboken</translation>
     </message>
     <message>
         <location filename="../passworddialog.ui" line="45"/>
+        <location filename="../obj-x86_64-linux-gnu/lxqt-sudo_autogen/include/ui_passworddialog.h" line="175"/>
         <source>&amp;Copy</source>
         <translation>&amp;Kopier</translation>
     </message>
     <message>
         <location filename="../passworddialog.ui" line="83"/>
+        <location filename="../obj-x86_64-linux-gnu/lxqt-sudo_autogen/include/ui_passworddialog.h" line="176"/>
         <source>The requested action needs administrative privileges.&lt;br&gt;Please enter your password.</source>
-        <translation>Den forespurte handlingen krever administrative privilegier.&lt;br&gt;Vennligst tast inn ditt passord.</translation>
+        <translation>Den forespurte handlingen krever administrative tillatelser.&lt;br&gt;Vennligst tast inn ditt passord.</translation>
     </message>
     <message>
         <location filename="../passworddialog.ui" line="106"/>
+        <location filename="../obj-x86_64-linux-gnu/lxqt-sudo_autogen/include/ui_passworddialog.h" line="178"/>
         <source>LXQt sudo backend</source>
         <translation>LXQt sudo-backend</translation>
     </message>
     <message>
         <location filename="../passworddialog.ui" line="109"/>
-        <source>A program LXQt sudo calls in background to elevate priveledges.</source>
-        <translation>Et program LXQt sudo bruker i bakgrunnen for å heve privilegier.</translation>
+        <location filename="../obj-x86_64-linux-gnu/lxqt-sudo_autogen/include/ui_passworddialog.h" line="181"/>
+        <source>A program LXQt sudo calls in background to elevate privileges.</source>
+        <translation>Et program LXQT sudo kontakter i bakgrunnen for å heve tillatelser.</translation>
     </message>
     <message>
         <location filename="../passworddialog.ui" line="119"/>
+        <location filename="../obj-x86_64-linux-gnu/lxqt-sudo_autogen/include/ui_passworddialog.h" line="183"/>
         <source>Command:</source>
         <translation>Kommando:</translation>
     </message>
     <message>
         <location filename="../passworddialog.ui" line="126"/>
+        <location filename="../obj-x86_64-linux-gnu/lxqt-sudo_autogen/include/ui_passworddialog.h" line="184"/>
         <source>Password:</source>
         <translation>Passord:</translation>
     </message>
     <message>
         <location filename="../passworddialog.ui" line="133"/>
+        <location filename="../obj-x86_64-linux-gnu/lxqt-sudo_autogen/include/ui_passworddialog.h" line="186"/>
         <source>Enter password</source>
         <translation>Tast inn passord</translation>
     </message>
@@ -57,7 +66,7 @@
 <context>
     <name>QObject</name>
     <message>
-        <location filename="../sudo.cpp" line="67"/>
+        <location filename="../sudo.cpp" line="69"/>
         <source>Usage: %1 option [command [arguments...]]
 
 GUI frontend for %2/%3
@@ -72,7 +81,7 @@ Arguments:
   arguments        Optional arguments for command.
 
 </source>
-        <translation>Bruk: %1 valg [kommandd [argumenter...]]
+        <translation>Bruk: %1 valg [kommando [argumenter...]]
 
 GUI-visning for %2/%3
 
@@ -88,7 +97,7 @@ Argumenter:
 </translation>
     </message>
     <message>
-        <location filename="../sudo.cpp" line="84"/>
+        <location filename="../sudo.cpp" line="86"/>
         <source>%1 version %2
 </source>
         <translation>%1 versjon %2
@@ -98,52 +107,52 @@ Argumenter:
 <context>
     <name>Sudo</name>
     <message>
-        <location filename="../sudo.cpp" line="183"/>
+        <location filename="../sudo.cpp" line="189"/>
         <source>%1: no command to run provided!</source>
-        <translation>%1: ingen kommando å kjøre!</translation>
+        <translation>%1: ingen kommando å kjøre oppgitt!</translation>
     </message>
     <message>
-        <location filename="../sudo.cpp" line="190"/>
+        <location filename="../sudo.cpp" line="196"/>
         <source>%1: no backend chosen!</source>
         <translation>%1: ingen backend valgt!</translation>
     </message>
     <message>
-        <location filename="../sudo.cpp" line="207"/>
+        <location filename="../sudo.cpp" line="213"/>
         <source>Syscall error, failed to fork: %1</source>
         <translation>Feil med Syscall. Klarte ikke å dele: %1</translation>
     </message>
     <message>
-        <location filename="../sudo.cpp" line="234"/>
+        <location filename="../sudo.cpp" line="240"/>
         <source>unset</source>
         <extracomment>shouldn&apos;t be actually used but keep as short as possible in translations just in case.</extracomment>
-        <translation>fjern</translation>
+        <translation>nullstill</translation>
     </message>
     <message>
-        <location filename="../sudo.cpp" line="270"/>
+        <location filename="../sudo.cpp" line="289"/>
         <source>%1: Detected attempt to inject privileged command via LC_ALL env(%2). Exiting!
 </source>
-        <translation>%1: Oppdaget et forsøk på å legge inn en priviligert kommando via LC_ALL env (%2). Avslutter!
+        <translation>%1: Oppdaget et forsøk på å legge inn en kommando som krever høye tillatelser via LC_ALL env (%2). Avslutter!
 </translation>
     </message>
     <message>
-        <location filename="../sudo.cpp" line="314"/>
+        <location filename="../sudo.cpp" line="331"/>
         <source>Syscall error, failed to bring pty to non-block mode: %1</source>
         <translation>Feil med Syscall. Klarte ikke å bringe pty til non-block modus: %1</translation>
     </message>
     <message>
-        <location filename="../sudo.cpp" line="322"/>
+        <location filename="../sudo.cpp" line="339"/>
         <source>Syscall error, failed to fdopen pty: %1</source>
         <translation>Feil med Syscall. Klarte ikke å kjøre fdopen pty: %1</translation>
     </message>
     <message>
-        <location filename="../sudo.cpp" line="291"/>
+        <location filename="../sudo.cpp" line="308"/>
         <source>%1: Failed to exec &apos;%2&apos;: %3
 </source>
         <translation>%1: Kunne ikke kjøre &apos;%2&apos;: %3
 </translation>
     </message>
     <message>
-        <location filename="../sudo.cpp" line="353"/>
+        <location filename="../sudo.cpp" line="370"/>
         <source>Child &apos;%1&apos; process failed!
 %2</source>
         <translation>Underprossessn &apos;%1&apos; feilet!
