@@ -5,48 +5,57 @@
     <name>PasswordDialog</name>
     <message>
         <location filename="../passworddialog.ui" line="6"/>
+        <location filename="../obj-x86_64-linux-gnu/lxqt-sudo_autogen/include/ui_passworddialog.h" line="171"/>
         <source>LXQt sudo</source>
         <translation>LXQt sudo</translation>
     </message>
     <message>
         <location filename="../passworddialog.ui" line="42"/>
+        <location filename="../obj-x86_64-linux-gnu/lxqt-sudo_autogen/include/ui_passworddialog.h" line="173"/>
         <source>Copy command to clipboard</source>
-        <translation type="unfinished"></translation>
+        <translation>Kopieer de opdracht naar het klembord</translation>
     </message>
     <message>
         <location filename="../passworddialog.ui" line="45"/>
+        <location filename="../obj-x86_64-linux-gnu/lxqt-sudo_autogen/include/ui_passworddialog.h" line="175"/>
         <source>&amp;Copy</source>
-        <translation type="unfinished"></translation>
+        <translation>&amp;Kopiëren</translation>
     </message>
     <message>
         <location filename="../passworddialog.ui" line="83"/>
+        <location filename="../obj-x86_64-linux-gnu/lxqt-sudo_autogen/include/ui_passworddialog.h" line="176"/>
         <source>The requested action needs administrative privileges.&lt;br&gt;Please enter your password.</source>
-        <translation type="unfinished"></translation>
+        <translation>De gevraagde actie heeft beheerdersrechten nodig.&lt;br&gt;Voer uw wachtwoord in.</translation>
     </message>
     <message>
         <location filename="../passworddialog.ui" line="106"/>
+        <location filename="../obj-x86_64-linux-gnu/lxqt-sudo_autogen/include/ui_passworddialog.h" line="178"/>
         <source>LXQt sudo backend</source>
-        <translation type="unfinished"></translation>
+        <translation>LXQt sudo backend</translation>
     </message>
     <message>
         <location filename="../passworddialog.ui" line="109"/>
-        <source>A program LXQt sudo calls in background to elevate priveledges.</source>
-        <translation type="unfinished"></translation>
+        <location filename="../obj-x86_64-linux-gnu/lxqt-sudo_autogen/include/ui_passworddialog.h" line="181"/>
+        <source>A program LXQt sudo calls in background to elevate privileges.</source>
+        <translation>Het programma dat LXQt sudo in de achtergrond aanroept om meer rechten te geven.</translation>
     </message>
     <message>
         <location filename="../passworddialog.ui" line="119"/>
+        <location filename="../obj-x86_64-linux-gnu/lxqt-sudo_autogen/include/ui_passworddialog.h" line="183"/>
         <source>Command:</source>
         <translation>Opdracht:</translation>
     </message>
     <message>
         <location filename="../passworddialog.ui" line="126"/>
+        <location filename="../obj-x86_64-linux-gnu/lxqt-sudo_autogen/include/ui_passworddialog.h" line="184"/>
         <source>Password:</source>
         <translation>Wachtwoord:</translation>
     </message>
     <message>
         <location filename="../passworddialog.ui" line="133"/>
+        <location filename="../obj-x86_64-linux-gnu/lxqt-sudo_autogen/include/ui_passworddialog.h" line="186"/>
         <source>Enter password</source>
-        <translation type="unfinished"></translation>
+        <translation>Voer wachtwoord in</translation>
     </message>
     <message>
         <location filename="../passworddialog.cpp" line="60"/>
@@ -57,7 +66,7 @@
 <context>
     <name>QObject</name>
     <message>
-        <location filename="../sudo.cpp" line="67"/>
+        <location filename="../sudo.cpp" line="69"/>
         <source>Usage: %1 option [command [arguments...]]
 
 GUI frontend for %2/%3
@@ -88,7 +97,7 @@ Argumenten:
 </translation>
     </message>
     <message>
-        <location filename="../sudo.cpp" line="84"/>
+        <location filename="../sudo.cpp" line="86"/>
         <source>%1 version %2
 </source>
         <translation>%1 versie %2
@@ -98,51 +107,52 @@ Argumenten:
 <context>
     <name>Sudo</name>
     <message>
-        <location filename="../sudo.cpp" line="183"/>
+        <location filename="../sudo.cpp" line="189"/>
         <source>%1: no command to run provided!</source>
         <translation>%1: geen uit te voeren opdracht opgegeven.</translation>
     </message>
     <message>
-        <location filename="../sudo.cpp" line="190"/>
+        <location filename="../sudo.cpp" line="196"/>
         <source>%1: no backend chosen!</source>
         <translation>%1: geen achtergronddienst gekozen.</translation>
     </message>
     <message>
-        <location filename="../sudo.cpp" line="207"/>
+        <location filename="../sudo.cpp" line="213"/>
         <source>Syscall error, failed to fork: %1</source>
-        <translation type="unfinished"></translation>
+        <translation>Syscall-fout, kan niet worden geprepareerd: %1</translation>
     </message>
     <message>
-        <location filename="../sudo.cpp" line="234"/>
+        <location filename="../sudo.cpp" line="240"/>
         <source>unset</source>
         <extracomment>shouldn&apos;t be actually used but keep as short as possible in translations just in case.</extracomment>
-        <translation type="unfinished"></translation>
+        <translation>niet ingesteld</translation>
     </message>
     <message>
-        <location filename="../sudo.cpp" line="270"/>
+        <location filename="../sudo.cpp" line="289"/>
         <source>%1: Detected attempt to inject privileged command via LC_ALL env(%2). Exiting!
 </source>
-        <translation type="unfinished"></translation>
+        <translation>%1: Gedetecteerde poging om bevoorrechte opdracht te injecteren via LC_ALL env(%2). Afsluiten!
+</translation>
     </message>
     <message>
-        <location filename="../sudo.cpp" line="314"/>
+        <location filename="../sudo.cpp" line="331"/>
         <source>Syscall error, failed to bring pty to non-block mode: %1</source>
-        <translation type="unfinished"></translation>
+        <translation>Syscall-fout, mislukt om pty naar niet-blokkeermodus aan te passen: %1</translation>
     </message>
     <message>
-        <location filename="../sudo.cpp" line="322"/>
+        <location filename="../sudo.cpp" line="339"/>
         <source>Syscall error, failed to fdopen pty: %1</source>
-        <translation type="unfinished"></translation>
+        <translation>Syscall-fout, niet in geslaagd om pty te fdopen: %1</translation>
     </message>
     <message>
-        <location filename="../sudo.cpp" line="291"/>
+        <location filename="../sudo.cpp" line="308"/>
         <source>%1: Failed to exec &apos;%2&apos;: %3
 </source>
         <translation>%1: Kon &apos;%2&apos; niet uitvoeren: %3
 </translation>
     </message>
     <message>
-        <location filename="../sudo.cpp" line="353"/>
+        <location filename="../sudo.cpp" line="370"/>
         <source>Child &apos;%1&apos; process failed!
 %2</source>
         <translation>Afgeleid proces &apos;%1&apos; is mislukt.
