@@ -5,46 +5,55 @@
     <name>PasswordDialog</name>
     <message>
         <location filename="../passworddialog.ui" line="6"/>
+        <location filename="../obj-x86_64-linux-gnu/lxqt-sudo_autogen/include/ui_passworddialog.h" line="171"/>
         <source>LXQt sudo</source>
         <translation>LXQt sudo</translation>
     </message>
     <message>
         <location filename="../passworddialog.ui" line="42"/>
+        <location filename="../obj-x86_64-linux-gnu/lxqt-sudo_autogen/include/ui_passworddialog.h" line="173"/>
         <source>Copy command to clipboard</source>
         <translation>Copiar comando para área de trabalho</translation>
     </message>
     <message>
         <location filename="../passworddialog.ui" line="45"/>
+        <location filename="../obj-x86_64-linux-gnu/lxqt-sudo_autogen/include/ui_passworddialog.h" line="175"/>
         <source>&amp;Copy</source>
         <translation>&amp;Copiar</translation>
     </message>
     <message>
         <location filename="../passworddialog.ui" line="83"/>
+        <location filename="../obj-x86_64-linux-gnu/lxqt-sudo_autogen/include/ui_passworddialog.h" line="176"/>
         <source>The requested action needs administrative privileges.&lt;br&gt;Please enter your password.</source>
         <translation>A ação solicitada necessita de privilégios administrativos.&lt;br&gt;Introduza a sua palavra-passe.</translation>
     </message>
     <message>
         <location filename="../passworddialog.ui" line="106"/>
+        <location filename="../obj-x86_64-linux-gnu/lxqt-sudo_autogen/include/ui_passworddialog.h" line="178"/>
         <source>LXQt sudo backend</source>
         <translation>Infraestrutura LXQt sudo</translation>
     </message>
     <message>
         <location filename="../passworddialog.ui" line="109"/>
-        <source>A program LXQt sudo calls in background to elevate priveledges.</source>
-        <translation>Um programa LXQt sudo a correr em segundo plano pede para elevar privilégios.</translation>
+        <location filename="../obj-x86_64-linux-gnu/lxqt-sudo_autogen/include/ui_passworddialog.h" line="181"/>
+        <source>A program LXQt sudo calls in background to elevate privileges.</source>
+        <translation>Um programa LXQt su para elevar os privilégios de administrador.</translation>
     </message>
     <message>
         <location filename="../passworddialog.ui" line="119"/>
+        <location filename="../obj-x86_64-linux-gnu/lxqt-sudo_autogen/include/ui_passworddialog.h" line="183"/>
         <source>Command:</source>
         <translation>Comando:</translation>
     </message>
     <message>
         <location filename="../passworddialog.ui" line="126"/>
+        <location filename="../obj-x86_64-linux-gnu/lxqt-sudo_autogen/include/ui_passworddialog.h" line="184"/>
         <source>Password:</source>
         <translation>Palavra-passe:</translation>
     </message>
     <message>
         <location filename="../passworddialog.ui" line="133"/>
+        <location filename="../obj-x86_64-linux-gnu/lxqt-sudo_autogen/include/ui_passworddialog.h" line="186"/>
         <source>Enter password</source>
         <translation>Introduza a palavra-passe</translation>
     </message>
@@ -57,7 +66,7 @@
 <context>
     <name>QObject</name>
     <message>
-        <location filename="../sudo.cpp" line="67"/>
+        <location filename="../sudo.cpp" line="69"/>
         <source>Usage: %1 option [command [arguments...]]
 
 GUI frontend for %2/%3
@@ -88,7 +97,7 @@ Argumentos:
 </translation>
     </message>
     <message>
-        <location filename="../sudo.cpp" line="84"/>
+        <location filename="../sudo.cpp" line="86"/>
         <source>%1 version %2
 </source>
         <translation>%1 versão %2
@@ -98,52 +107,52 @@ Argumentos:
 <context>
     <name>Sudo</name>
     <message>
-        <location filename="../sudo.cpp" line="183"/>
+        <location filename="../sudo.cpp" line="189"/>
         <source>%1: no command to run provided!</source>
         <translation>%1: comando não especificado!</translation>
     </message>
     <message>
-        <location filename="../sudo.cpp" line="190"/>
+        <location filename="../sudo.cpp" line="196"/>
         <source>%1: no backend chosen!</source>
         <translation>%1: infraestrutura não escolhida!</translation>
     </message>
     <message>
-        <location filename="../sudo.cpp" line="207"/>
+        <location filename="../sudo.cpp" line="213"/>
         <source>Syscall error, failed to fork: %1</source>
         <translation>Erro &apos;syscall&apos;, falha ao clonar: %1</translation>
     </message>
     <message>
-        <location filename="../sudo.cpp" line="234"/>
+        <location filename="../sudo.cpp" line="240"/>
         <source>unset</source>
         <extracomment>shouldn&apos;t be actually used but keep as short as possible in translations just in case.</extracomment>
         <translation>indefinido</translation>
     </message>
     <message>
-        <location filename="../sudo.cpp" line="270"/>
+        <location filename="../sudo.cpp" line="289"/>
         <source>%1: Detected attempt to inject privileged command via LC_ALL env(%2). Exiting!
 </source>
         <translation>%1: Detetada uma tentativa de injetar um comando privilegiado via LC_ALL (%2). A sair!
 </translation>
     </message>
     <message>
-        <location filename="../sudo.cpp" line="314"/>
+        <location filename="../sudo.cpp" line="331"/>
         <source>Syscall error, failed to bring pty to non-block mode: %1</source>
         <translation>Erro &apos;syscall&apos;, falha ao trazer pty para modo não bloco: %1</translation>
     </message>
     <message>
-        <location filename="../sudo.cpp" line="322"/>
+        <location filename="../sudo.cpp" line="339"/>
         <source>Syscall error, failed to fdopen pty: %1</source>
         <translation>Erro &apos;syscall&apos;, falha ao fdopen pty: %1</translation>
     </message>
     <message>
-        <location filename="../sudo.cpp" line="291"/>
+        <location filename="../sudo.cpp" line="308"/>
         <source>%1: Failed to exec &apos;%2&apos;: %3
 </source>
         <translation>%1: falha ao executar %2: %3
 </translation>
     </message>
     <message>
-        <location filename="../sudo.cpp" line="353"/>
+        <location filename="../sudo.cpp" line="370"/>
         <source>Child &apos;%1&apos; process failed!
 %2</source>
         <translation>Falha no processo dependente %1!
